# CSV
ingestr supports CSV files as source and destination. This allows copying data from any database into a local CSV file, as well as uploading data from the local CSV files into database tables.

## URI format
The URI format for CSV files is as follows:

```plaintext
csv://path/to/csv/file.csv
```
